@@ -731,12 +731,40 @@ class FakePathlibModule:
         """
         __slots__ = ()
 
+        def owner(self):
+            raise NotImplementedError(
+                "Path.owner() is unsupported on this system")
+
+        def group(self):
+            raise NotImplementedError(
+                "Path.group() is unsupported on this system")
+
+        def is_mount(self):
+            raise NotImplementedError(
+                "Path.is_mount() is unsupported on this system")
+
     class PosixPath(FakePath, PurePosixPath):
         """A subclass of Path and PurePosixPath that represents
         concrete non-Windows filesystem paths.
         """
         __slots__ = ()
 
+        def owner(self):
+            """Return the current user name. It is assumed that the fake
+            file system was created by the current user.
+            """
+            import pwd
+
+            return pwd.getpwuid(os.getuid()).pw_name
+
+        def group(self):
+            """Return the current group name. It is assumed that the fake
+            file system was created by the current user.
+            """
+            import grp
+
+            return grp.getgrgid(os.getgid()).gr_name
+
     Path = FakePath
 
     def __getattr__(self, name):
@@ -817,6 +845,12 @@ class RealPathlibPathModule:
     """Patches `pathlib.Path` by passing all calls to RealPathlibModule."""
     real_pathlib = None
 
+    @classmethod
+    def __instancecheck__(cls, instance):
+        # as we cannot derive from pathlib.Path, we fake
+        # the inheritance to pass isinstance checks - see #666
+        return isinstance(instance, PurePath)
+
     def __init__(self):
         if self.real_pathlib is None:
             self.__class__.real_pathlib = RealPathlibModule()
