@@ -8,11 +8,17 @@ def my_fakefs_test(fs):
     fs.create_file('/var/data/xx1.txt')
     assert os.path.exists('/var/data/xx1.txt')
 """
-
+import _pytest
+import py
 import pytest
 
 from pyfakefs.fake_filesystem_unittest import Patcher
 
+Patcher.SKIPMODULES.add(py)
+Patcher.SKIPMODULES.add(pytest)
+if hasattr(_pytest, "pathlib"):
+    Patcher.SKIPMODULES.add(_pytest.pathlib)
+
 
 @pytest.fixture
 def fs(request):
